
django-custom-accounts-plus

This package stores password histories and checks new password with the history


Quick start
-----------
1. Add "password_histories" to your INSTALLED_APPS setting like this::
``
INSTALLED_APPS = [
...
'password_histories',
]
``

2. Migrate
``
python manage.py migrate
``

TODO
----

Changelog
---------
1.0.0 - 2023-02-26 Arindam Dutta - First release

Copyright(c) 2023 Arindam Dutta
